@@ -23,11 +23,13 @@
 #'   of the silhouette (0 is fully transparent, 1 is fully opaque).
 #' @param color \code{character}. Color of silhouette outline. If "original" or
 #'   NA is specified, the original color of the silhouette outline will be used
-#'   (usually the same as "transparent").
+#'   (usually the same as "transparent"). To remove the outline, you can set
+#'   this to "transparent".
 #' @param fill \code{character}. Color of silhouette. If "original" is
 #'   specified, the original color of the silhouette will be used (usually the
-#'   same as "black"). If `color` is specified and `fill` is NA the outline and
-#'   fill color will be the same.
+#'   same as "black"). If `color` is specified and `fill` is NA, `color` will be
+#'   used as the fill color (for backwards compatibility). To remove the fill,
+#'   you can set this to "transparent".
 #' @param horizontal \code{logical}. Should the silhouette be flipped
 #'   horizontally?
 #' @param vertical \code{logical}. Should the silhouette be flipped vertically?
@@ -62,7 +64,7 @@
 #' @importFrom grImport2 grid.picture
 #' @importFrom methods is slotNames
 #' @export
-#' @examples
+#' @examples \dontrun{
 #' # single image
 #' plot(1, 1, type = "n", main = "A cat")
 #' add_phylopic_base(uuid = "23cd6aa4-9587-4a2e-8e26-de42885004c9",
@@ -75,13 +77,13 @@
 #' angle <- runif(10, 0, 360)
 #' hor <- sample(c(TRUE, FALSE), 10, TRUE)
 #' ver <- sample(c(TRUE, FALSE), 10, TRUE)
-#' cols <- sample(c("black", "darkorange", "grey42", "white"), 10,
+#' fills <- sample(c("black", "darkorange", "grey42", "white"), 10,
 #'                replace = TRUE)
 #'
 #' plot(posx, posy, type = "n", main = "A cat herd")
 #' add_phylopic_base(uuid = "23cd6aa4-9587-4a2e-8e26-de42885004c9",
 #'                   x = posx, y = posy, ysize = size,
-#'                   color = cols, angle = angle,
+#'                   fill = fills, angle = angle,
 #'                   horizontal = hor, vertical = ver)
 #'
 #' # Example using a cat background
@@ -93,10 +95,11 @@
 #' add_phylopic_base(img = cat, alpha = 0.2)
 #' # overlay smaller cats
 #' add_phylopic_base(img = cat, x = posx, y = posy, ysize = size, alpha = 0.8)
+#' }
 add_phylopic_base <- function(img = NULL, name = NULL, uuid = NULL,
                               filter = NULL,
                               x = NULL, y = NULL, ysize = NULL,
-                              alpha = 1, color = "black", fill = NA,
+                              alpha = 1, color = NA, fill = "black",
                               horizontal = FALSE, vertical = FALSE, angle = 0,
                               remove_background = TRUE, verbose = FALSE) {
   if (all(sapply(list(img, name, uuid), is.null))) {
@@ -190,9 +193,12 @@ add_phylopic_base <- function(img = NULL, name = NULL, uuid = NULL,
     if (angle != 0) img <- rotate_phylopic(img, angle)
 
     # recolor if necessary
-    color <- if (is.na(color) || color == "original") NULL else color
-    if (is.na(fill)) fill <- color
-    fill <- if (fill == "original") NULL else fill
+    if (is.na(color) || color == "original") color <- NULL
+    if (is.na(fill)) {
+      fill <- color
+      color <- NULL
+    }
+    if (fill == "original") fill <- NULL
     img <- recolor_phylopic(img, alpha, color, fill, remove_background)
 
     # grobify and plot
